#### Load packages ####
if (!require(data.table)) install.packages("data.table")
if (!require(sp)) install.packages("sp")
if (!require(gstat)) install.packages("gstat")

require(data.table)
require(sp)
require(gstat)


#### Proportion of potential timber volume ####

volRadam = read.csv("volRadam.csv")
plotInfo = read.csv("plotInfo.csv")

omegaData = data.table(rbind(volRadam[,c("longitude","latitude","omegaTot")], 
                             plotInfo[,c("longitude","latitude","omegaTot")]))


### problem: we have repeated coordinates ###
# we average the omega values in duplicated sites #
omegaData = omegaData[,.(omegaTot = mean(omegaTot)),.(longitude,latitude)]
## proportion (0<om<1) -> transform with logit 
omegaData$logit_om = log(omegaData$omegaTot/(1-omegaData$omegaTot))
## some values are 0 or 1 (in a continuous world, they would only be very close to 0 or 1, but trees are discrete entities)
## correct by eps = smallest interval between a value and 1 ( eps > 0 )
eps = (1-max(omegaData$omegaTot[omegaData$omegaTot!=1]))/2
omegaData$logit_om[omegaData$omegaTot==0] <- log(eps/(1-eps))
omegaData$logit_om[omegaData$omegaTot==1] <- log((1-eps)/eps)

# omegaData -> spatial object
coordinates(omegaData) = ~longitude + latitude
# reproject for kriging
proj4string(omegaData) <- CRS("+proj=longlat +datum=WGS84")
# omegaData <-  spTransform(omegaData, CRS("+proj=utm +zone=22"))

# creating the kriging grid
grd2 <- expand.grid(x=seq(from=-79.5, to=-44.5, by=1), y=seq(from=-19.5, to=9.5, by=1))
coordinates(grd2) <- ~ x+y
gridded(grd2) <- TRUE
proj4string(grd2) <- CRS("+proj=longlat +datum=WGS84")

# kriging
# choosing a variogram model
semivariog <- variogram(logit_om~1, locations=omegaData, data=omegaData)
plot(semivariog)
model.variog <- vgm(psill=0.7, model="Sph", nugget=3.75, range=1500)
plot(semivariog, model.variog)

krig <- krige(formula = logit_om ~ 1, locations=omegaData, newdata=grd2, model=model.variog)
krig.output <- as.data.frame(krig)
names(krig.output)[1:3] <- c("long","lat","logit_om")
dataStemMort <- data.frame(omegaData)

## extract values ##
grd$mean_logit_om <- raster::extract(raster(krig,"var1.pred"),grd)
grd$var_logit_om <- raster::extract(raster(krig,"var1.var"),grd)


#### Stem mortality ####

### data downloaded from https://www.forestplots.net/en/products ###
## Data Package: Johnson M. et al 2016. Plot data from: "Variation 
## in stem mortality rates determines patterns of aboveground biomass 
## in Amazonian forests: implications for dynamic global vegetation models"

## open data
dataStemMort <- read.csv("Plot_summary_data.csv")
dataStemMort$site = substr(dataStemMort$Plot_code, 1,3)
## avoid duplicated coordinates
dataStemMort = data.table(dataStemMort)[,.(mu = mean(X.)) , .(Longitude,Latitude)]
colnames(dataStemMort) = c("longitude","latitude","mu")
dataStemMort$logit_mu = log(dataStemMort$mu/(100-dataStemMort$mu))
  
coordinates(dataStemMort) = ~longitude + latitude
proj4string(dataStemMort) <-  CRS("+proj=longlat +datum=WGS84")

# create grid
grd2 <- expand.grid(x=seq(from=-79.5, to=-44.5, by=1), y=seq(from=-19.5, to=9.5, by=1))
coordinates(grd2) <- ~ x+y
gridded(grd2) <- TRUE
proj4string(grd2) <- CRS("+proj=longlat +datum=WGS84")

# kriging
# choose variogram model
semivariog <- variogram(logit_mu~1, locations=dataStemMort, data=dataStemMort)
plot(semivariog)
model.variog <- vgm(psill=0.5, model="Sph", nugget=0.1, range=4000)
plot(semivariog, model.variog)

krig <- krige(formula = logit_mu ~ 1, locations=dataStemMort, newdata=grd2, model=model.variog)
krig.output <- as.data.frame(krig)
names(krig.output)[1:3] <- c("long","lat","logit_mu")
dataStemMort <- data.frame(dataStemMort)

## extract values ##
grd$mean_logit_mort <- raster::extract(raster(krig,"var1.pred"),grd)
grd$var_logit_mort <- raster::extract(raster(krig,"var1.var"),grd)
